pub struct CoreEnvironment { /* private fields */ }Expand description
A platform-selected snapshot used to construct a core environment input.
Implementations
Sourceimpl CoreEnvironment
impl CoreEnvironment
Sourcepub fn from_selected<I>(variables: I) -> Result<Self, CommandError>
pub fn from_selected<I>(variables: I) -> Result<Self, CommandError>
Creates a validated core snapshot from variables selected by the process adapter.