EnvironmentInput

Struct EnvironmentInput 

pub struct EnvironmentInput { /* private fields */ }
A base environment selected by the process adapter.

The constructors encode the base that the variables represent. This keeps an EnvironmentSpec from being applied to an arbitrarily broad map while claiming that the map is empty or platform-core input.

Implementations

Source

impl EnvironmentInput

pub fn all<I>(variables: I) -> Result<Self, CommandError>
where I: IntoIterator<Item = (OsString, OsString)>,

Creates a validated input containing all inherited variables.

pub fn core(environment: CoreEnvironment) -> Self

Creates an input containing a process adapter’s selected core set.

pub fn empty() -> Self

Creates an input with no inherited variables.

pub const fn base(&self) -> EnvironmentBase

Returns the declared base represented by this input.

pub fn variables(&self) -> &BTreeMap<OsString, OsString>

Returns the variables represented by this input.

pub fn into_variables(self) -> BTreeMap<OsString, OsString>

Consumes the input and returns its selected variables.