StdioSpec

Struct StdioSpec 

pub struct StdioSpec { /* private fields */ }
Portable routing choices for stdin, stdout, and stderr.

Implementations

Source

impl StdioSpec

pub const fn new(stdin: StdioMode, stdout: StdioMode, stderr: StdioMode) -> Self

Creates explicit routing choices for all three standard streams.

pub const fn captured() -> Self

Creates the non-interactive default: closed stdin and captured output.

pub const fn inherited() -> Self

Creates a request that inherits all three standard streams.

pub const fn with_stdin(self, mode: StdioMode) -> Self

Replaces stdin routing.

pub const fn with_stdout(self, mode: StdioMode) -> Self

Replaces stdout routing.

pub const fn with_stderr(self, mode: StdioMode) -> Self

Replaces stderr routing.

pub const fn stdin(&self) -> StdioMode

Returns stdin routing.

pub const fn stdout(&self) -> StdioMode

Returns stdout routing.

pub const fn stderr(&self) -> StdioMode

Returns stderr routing.