pub struct EnvironmentInput { /* private fields */ }Expand description
A base environment selected by the process adapter.
The constructors encode the base that the variables represent. This keeps
an EnvironmentSpec from being applied to an arbitrarily broad map while
claiming that the map is empty or platform-core input.
Implementations
Sourceimpl EnvironmentInput
impl EnvironmentInput
Sourcepub fn all<I>(variables: I) -> Result<Self, CommandError>
pub fn all<I>(variables: I) -> Result<Self, CommandError>
Creates a validated input containing all inherited variables.
Sourcepub fn core(environment: CoreEnvironment) -> Self
pub fn core(environment: CoreEnvironment) -> Self
Creates an input containing a process adapter’s selected core set.
Sourcepub const fn base(&self) -> EnvironmentBase
pub const fn base(&self) -> EnvironmentBase
Returns the declared base represented by this input.
Sourcepub fn variables(&self) -> &BTreeMap<OsString, OsString>
pub fn variables(&self) -> &BTreeMap<OsString, OsString>
Returns the variables represented by this input.
Sourcepub fn into_variables(self) -> BTreeMap<OsString, OsString>
pub fn into_variables(self) -> BTreeMap<OsString, OsString>
Consumes the input and returns its selected variables.